@@ -1,8 +1,12 @@
 #ifndef __MULTI
 #define __MULTI
 
+#define SERVER 1
+#define CLIENT 2
+
 #define ADVERTISE_IP	"230.3.3.3"
 #define ADVERTISE_PORT	59000
+#define FTRANSFER_PORT	59001
 #define SERVER_IP	"127.0.0.1"
 #define SERVER_PORT	50000
 #define DEFAULT_IP	"231.0.0."
@@ -27,20 +31,39 @@
 #define CONFIG_FILE	"/etc/multivnc/multivnc_server.conf"
 #define CAST_PK_SIZE	1400
 #define INPUT_PRIORITY	120
+#define STRLENGTH	64
+// save to *.swf file (recorded file) in this directory
+// char limit is IDLENGTH * 2 = 32 char
+#define REC_PATH	"/tmp/"
+#define SWF_DATA	1024
+#define SLEEP		2
+
+#define START		1
+#define STOP		0
+#define CONTINUE	-1
 
 /* client state */
 #define STAT_FIRST	0
 #define STAT_ADV	1
 #define STAT_VNC	2
 #define STAT_CUT	3
+#define STAT_REC	4
+#define STAT_FILE	5
+
+/* casting state */
+#define CAST_WAIT       0
+#define CAST_SEND       1
+#define CAST_STOP       2
 
 /* state parameter */
-#define LOCKSTATE	0x80	/* å */
-#define RECVSTATE	0x40	/* ۿμ */
-#define SENDSTATE	0x20    /* ۿ */
-#define VIEWSTATE	0x08	/* ̳ɽ */
-#define CTRLSTATE	0x04	/*  */
 #define RESENDSTATE	0x01	/* 饤Ȥ̤׵ */
+#define RECSTATE	0x02	/* Ͽ */
+#define CTRLSTATE	0x04	/*  */
+#define VIEWSTATE	0x08	/* ̳ɽ */
+#define FILESTATE	0x10	/* եž */
+#define SENDSTATE	0x20    /* ۿ */
+#define RECVSTATE	0x40	/* ۿμ */
+#define LOCKSTATE	0x80	/* å */
 
 #if 1
 /* for server */
@@ -65,6 +88,13 @@
 #define GETRESEND(Num)		(server_CB.client_grp[(Num)]->state & RESENDSTATE)?1:0
 #define SETRESEND(Num, Flag)	(Flag)?(server_CB.client_grp[(Num)]->state |= RESENDSTATE):\
                                         (server_CB.client_grp[(Num)]->state &= ~RESENDSTATE)
+#define GETREC(Num)		(server_CB.client_grp[(Num)]->state & RECSTATE)?1:0
+#define SETREC(Num, Flag)	(Flag)?(server_CB.client_grp[(Num)]->state |= RECSTATE):\
+                                        (server_CB.client_grp[(Num)]->state &= ~RECSTATE)
+
+#define GETFILE(Num)		(server_CB.client_grp[(Num)]->state & FILESTATE)?1:0
+#define SETFILE(Num, Flag)	(Flag)?(server_CB.client_grp[(Num)]->state |= FILESTATE):\
+
 /* for client */
 #define GETLOCK_C		(client_CB.state & LOCKSTATE)?1:0
 #define SETLOCK_C(Flag)		(Flag)?(client_CB.state |= LOCKSTATE):(client_CB.state &= ~LOCKSTATE)
@@ -72,7 +102,11 @@
 #define SETRECV_C(Flag)		(Flag)?(client_CB.state |= RECVSTATE):(client_CB.state &= ~RECVSTATE)
 #define GETRESEND_C		(client_CB.state & RESENDSTATE)?1:0
 #define SETRESEND_C(Flag)	(Flag)?(client_CB.state |= RESENDSTATE):(client_CB.state &= ~RESENDSTATE)
-  
+#define GETREC_C		(client_CB.state & RECSTATE)?1:0
+#define SETREC_C(Flag)		(Flag)?(client_CB.state |= RECSTATE):(client_CB.state &= ~RECSTATE)
+#define GETFILE_C		(client_CB.state & FILESTATE)?1:0
+#define SETFILE_C(Flag)		(Flag)?(client_CB.state |= FILESTATE):(client_CB.state &= ~FILESTATE)
+
 #endif
 
 typedef struct {
@@ -97,8 +131,25 @@ typedef struct {
 	CARD8	fullscreen;
 	CARD8	src_ID[IDLENGTH];
 	rfbServerInitMsg serverInitMsg;
+	rfbPixelFormat pixelFormat;
 } CastAdv;
 
+typedef struct {
+	CARD8	type;
+	CARD8	flag;
+	CARD8	rectime;
+	CARD8	fps;
+	CARD8	geometry[IDLENGTH];
+} RecAdv;
+
+typedef struct {
+	CARD8	type;
+	CARD8	flag;
+	size_t	fsize;
+	CARD8	fname[STRLENGTH];
+	CARD8	data[MAXBUF];
+} FileAdv;
+
 typedef struct {
 	CARD8	type;
 	CARD8	flag;
@@ -163,6 +214,7 @@ struct client_grp {
 	gint calcrate_tag;
 	gint resend_tag;
 	int shm_id;
+	FILE *fp;
 };
 
 struct client_cb {
@@ -185,6 +237,7 @@ struct client_cb {
 	CARD32 g_cstdsp;
 	CARD32 connectstate;
 	rfbServerInitMsg serverInitMsg;
+	rfbPixelFormat serverFormat;
 	CARD16 del_pk_num;				/* ˴줿ѥåȿ */
 };
 
@@ -206,6 +259,7 @@ extern void ConnectVNC (struct sockaddr_in, int, int);
 int CreateMultiSockToSend (unsigned int ip, int port);
 extern void SendCastMsg (char flag, int clientNum, char fullscreen);
 extern void SendLockMsg (char flag, int clientNum);
+extern void SendRecMsg (char flag, int clientNum, int rectime,int fps,char* geometry);
 extern void SendAllowMsg (int clientNum, char *buf);
 extern void CutVNC (int clientNum);
 extern void SendVncMsg (int clientNum);
@@ -235,8 +289,13 @@ extern int client_main(int argc, char **argv);
 extern struct client_cb client_CB;
 extern void StartVNCServer (void);
 extern void CloseVNCServer (void);
+int adjustColorBitShift(short server_bits, short client_bits);
 extern int auto_flag;
 extern int notice_flag;
+//void start_record(void);
+void start_record(int framerate, char *geometry, char *path);
+void stop_record(void);
+void changeTwoDigit(char *string, int num);
 
 /* listen.c */
 extern void doListen();
@@ -303,6 +362,9 @@ GdkPixmap *pixmap_ex;
 GdkImage *smallimage_ex;
 extern GtkWidget *window_ex;
 
+/* main.c(client) */
+extern GtkIMContext *im_context;
+
 /* callbacks.c(client) */
 void open_dialog_recvAdv(char *);
 void GetMultiVNCServerMsg (void *);
