@@ -1,8 +1,9 @@
 /*****************************************************************************/
 /*** multivnc_client.c                                                       ***/
 /*****************************************************************************/
-#include <stdio.h>
-#include <string.h>
+
+#include "vncviewer.h"
+
 #include <sys/socket.h>
 #include <resolv.h>
 #include <errno.h>
@@ -10,12 +11,11 @@
 #include <getopt.h>
 #include <sys/types.h>
 #include <signal.h>
-
-#include "vncviewer.h"
 #include <jpeglib.h>
 #include <zlib.h>
 #include <fcntl.h>
 
+
 Bool JoinCTL ();
 void JoinVNC ();
 int CreateMultiSockToRecv (char *, short);
@@ -38,6 +38,7 @@ Display* dpy;
 char answer;
 int lock_time = 0;
 gint lock_tag;
+//gint record_tag;
 int auto_flag = 0;
 int notice_flag = 1;
 char connect_server[IDLENGTH] = "\0";
@@ -49,8 +50,6 @@ GtkWidget *dialog_recvAdv;
 GtkWidget *dialog_inputmiss;
 GtkWidget *lock_window;
 GtkWidget *mini_window;
-extern GtkWidget *client_drawingarea;
-extern GtkWidget *screen_label;
 
 /****/
 #define BGR233_SIZE 256
@@ -330,7 +329,7 @@ int client_main(int argc, char **argv)
       case '?':
       default:
 	help(argv[0]);
-	exit(1);
+	exit(EXIT_FAILURE);
 	break;
     }
   }
@@ -414,8 +413,9 @@ JoinCTL ()
   /* Send Client_ID */
   clientadv.type = rfbClientAdv;
   clientadv.length = sizeof(ClientAdv);
-  memcpy(clientadv.client_ID, client_CB.client_ID, 16);
+  memcpy(clientadv.client_ID, client_CB.client_ID, IDLENGTH);
   send (client_CB.ctldsp, &clientadv, sizeof(ClientAdv), 0);
+  printf("clientadv.client_ID: %s\n", client_CB.client_ID);
 
   return True;
 }
@@ -641,7 +641,7 @@ GetMultiVNCServerMsg (void *g_dsp)
     if (read (client_CB.ctldsp, buf, 2) <= 0) {
       CloseVNCServer();
       fprintf(stderr, "%s : session closed\n", programName);
-      exit (1);
+      exit (EXIT_FAILURE);
     }
     printf("type=%d, flag=%d\n",buf[0],buf[1]);
 
@@ -664,7 +664,7 @@ GetMultiVNCServerMsg (void *g_dsp)
 	if (read (client_CB.ctldsp, (char *)&castadv + 2, sizeof(CastAdv)-2) <= 0) {
 	  CloseVNCServer();
 	  fprintf(stderr, "%s : session closed\n", programName);
-	  exit (1);
+	  exit (EXIT_FAILURE);
 	}
 
 	if ((client_CB.connectstate == STAT_VNC) || (client_CB.connectstate == STAT_CUT)) {
@@ -692,6 +692,8 @@ GetMultiVNCServerMsg (void *g_dsp)
 	    drawing_window = (GtkWidget *)create_drawing_window();
 	    gtk_window_set_default_size(GTK_WINDOW(drawing_window), 600, 400);
 
+	    GtkWidget *screen_label = (GtkWidget *)lookup_widget(GTK_WIDGET(drawing_window), "screen_label");
+	    GtkWidget *client_drawingarea = (GtkWidget *)lookup_widget(GTK_WIDGET(drawing_window), "client_drawingarea");
 	    gtk_label_set_text(GTK_LABEL(screen_label), castadv.src_ID);
 
 	    drawingarea[0][0] = client_drawingarea;
@@ -726,7 +728,7 @@ GetMultiVNCServerMsg (void *g_dsp)
 	if (read (client_CB.ctldsp, (char *)&lockadv + 2, sizeof(LockAdv)-2) <= 0) {
 	  CloseVNCServer();
 	  fprintf(stderr, "%s : session closed\n", programName);
-	  exit (1);
+	  exit (EXIT_FAILURE);
 	}
 
 	if ((client_CB.connectstate == STAT_VNC) || (client_CB.connectstate == STAT_CUT)) {
@@ -746,20 +748,37 @@ GetMultiVNCServerMsg (void *g_dsp)
 	break;
       } 
 
+#if 0
       case rfbRecAdv:
       {
 	RecAdv recadv;
 
 	printf("switch : rfbRecAdv\n");
-	if (read (client_CB.ctldsp, (char *)&recadv + 2, sizeof(RecAdv)-2) <= 0) {
+	if (recv (client_CB.ctldsp, (char *)&recadv + 2, sizeof(recadv)-2, 0) <= 0) {
 	  CloseVNCServer();
 	  fprintf(stderr, "%s : session closed\n", programName);
-	  exit (1);
+	  exit (EXIT_FAILURE);
+	}
+
+	if ((client_CB.connectstate == STAT_VNC) || (client_CB.connectstate == STAT_CUT)) {
+	  switch (buf[1]) {
+	    case START:
+	      fprintf(stderr, "recording time:%d fps:%d\n", recadv.rectime, recadv.fps);  
+	      start_record(recadv.fps,recadv.geometry, REC_PATH);
+	      record_tag = gtk_timeout_add(recadv.rectime * 1000, stop_record, NULL);
+	    break;
+
+	    case STOP:
+	      stop_record();
+	    break;
+
+	    default:
+	  }
 	}
-	
 	break;
       }
 
+#endif
       case rfbVncConnAdv:
         client_CB.connectstate = buf[1];
 	break;
