@@ -883,9 +883,9 @@ SendCast (int cnum)
   dest.sin_addr.s_addr = server_CB.casting_ip[server_CB.client_grp[cnum]->cast_grp];
   dest.sin_port = server_CB.casting_port;
 
-  while ((*shm_asym[cnum]).flag != 2) {
+  while ((*shm_asym[cnum]).flag != CAST_STOP) {
     if (getppid() == 1) exit(1);
-    if (((*shm_asym[cnum]).flag != 1) || ((*shm_asym[cnum]).end - (*shm_asym[cnum]).start == 0) ||
+    if (((*shm_asym[cnum]).flag != CAST_SEND) || ((*shm_asym[cnum]).end - (*shm_asym[cnum]).start == 0) ||
 	((*shm_asym[cnum]).rec_s - (*shm_asym[cnum]).rec_e == 0)) {
       (*shm_asym[cnum]).ave_delay = 0;
       usleep(1);
@@ -893,7 +893,7 @@ SendCast (int cnum)
     }
     int tmpcp = (*shm_asym[cnum]).rec_size[(*shm_asym[cnum]).rec_s];
    
-    while ((tmpcp) && ((*shm_asym[cnum]).flag != 2)) {
+    while ((tmpcp) && ((*shm_asym[cnum]).flag != CAST_STOP)) {
       //if (tmpcp == 0) continue;
       if (sendcnt > (*shm_asym[cnum]).sendrate) {
         usleep(1);
@@ -979,7 +979,7 @@ calcRate(int cnum)
     }
     /* ʲǤ */
     //printf("maxdelay=%d\n",maxdelay);
-    //if (maxdelay > 4000) (*shm_asym[server_CB.client_grp[i]->cast_grp]).flag = 0;
+    //if (maxdelay > 4000) (*shm_asym[server_CB.client_grp[i]->cast_grp]).flag = CAST_WAIT;
   }
 
   return rate_alg(maxdelay, cnum);
@@ -1032,7 +1032,7 @@ rfbCastUpdateBuf(char *buf, int len, char push)
 {
   if (GETSEND (clientNum)) {
     //if (push == 1) (*shm_asym).flag = 1;
-    (*shm_asym[clientNum]).flag = 1;
+    (*shm_asym[clientNum]).flag = CAST_SEND;
     if (len) {
       if ((*shm_asym[clientNum]).end - (*shm_asym[clientNum]).start >= 0) {
 	if (((*shm_asym[clientNum]).end + len) <= CAST_BUF_SIZE) {
@@ -1079,7 +1079,7 @@ rfbCastUpdateBuf(char *buf, int len, char push)
 void
 wait_buf (int cnum, int len)
 {
-  (*shm_asym[cnum]).flag = 1;
+  (*shm_asym[cnum]).flag = CAST_SEND;
   while (1) {
     if (((*shm_asym[cnum]).end - (*shm_asym[cnum]).start >= 0) && 
         ((((*shm_asym[cnum]).end + len) <= CAST_BUF_SIZE) || ((*shm_asym[cnum]).start > len))) break;
